/*-------------------------------------------------------------------------+
| Copyright 2014 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.annotation.editingsupport;

import org.eclipse.jface.viewers.CellEditor;
import org.eclipse.jface.viewers.CheckboxCellEditor;
import org.eclipse.jface.viewers.ColumnViewer;
import org.eclipse.jface.viewers.EditingSupport;
import org.eclipse.jface.viewers.TableViewer;
import org.fortiss.tooling.base.annotation.AnnotationEntry;
import org.fortiss.tooling.base.model.element.IAnnotatedSpecification;

/**
 * {@link EditingSupport} providing a check box to display and manipulate boolean annotation values.
 * 
 * @author diewald
 */
public class CheckBoxEditingSupport extends AnnotationEditingSupportBase {

	/** Placeholder for the boolean value editor (in fact, only an icon is toggled). */
	private CheckboxCellEditor checkBoxEditor;

	/** Constructs a new {@link CheckBoxEditingSupport}. */
	public CheckBoxEditingSupport(ColumnViewer viewer,
			Class<? extends IAnnotatedSpecification> specClass, String instanceKey) {
		super(viewer, specClass, instanceKey);
		checkBoxEditor = new CheckboxCellEditor(((TableViewer)viewer).getTable());
	}

	/** {@inheritDoc} */
	@Override
	protected CellEditor getCellEditor(Object element) {
		if(!(element instanceof AnnotationEntry)) {
			return null;
		}

		return checkBoxEditor;
	}
}
