/*-------------------------------------------------------------------------+
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.contentprovider;

import org.eclipse.jface.layout.GridDataFactory;
import org.eclipse.jface.viewers.IStructuredContentProvider;
import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.jface.viewers.Viewer;
import org.eclipse.jface.viewers.ViewerSorter;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Table;

/**
 * Base class configuring default table viewer.
 * 
 * @author ratiu
 */
public abstract class TableContentProviderBase implements IStructuredContentProvider {

	/** Compares content objects. */
	protected abstract int compare(Viewer viewer, Object o1, Object o2);

	/** Returns the content object. */
	protected abstract Object getContentObject();

	/** Creates the viewer columns. */
	protected abstract void createColumns(TableViewer viewer);

	/**
	 * Returns the the table widget. May be overridden by sub-classes to
	 * customize the widget.
	 */
	protected Table getTableWidget(Composite parent) {
		Table table =
				new Table(parent, SWT.SINGLE | SWT.H_SCROLL | SWT.V_SCROLL | SWT.FULL_SELECTION);
		GridDataFactory.fillDefaults().hint(485, 250).span(1, 5).applyTo(table);
		table.setLinesVisible(true);
		table.setHeaderVisible(true);
		return table;
	}

	/** Creates the table viewer on the given table. */
	public TableViewer createTableViewer(Composite parent) {
		TableViewer viewer = new TableViewer(getTableWidget(parent));
		createColumns(viewer);

		viewer.setSorter(new TableViewerSorter());
		viewer.setContentProvider(this);
		viewer.setInput(getContentObject());

		return viewer;
	}

	/** {@inheritDoc} */
	@Override
	public void dispose() {
		// default implementation does nothing
	}

	/** {@inheritDoc} */
	@Override
	public void inputChanged(Viewer viewer, Object oldInput, Object newInput) {
		// default implementation ignores the input changed event
	}

	/** ViewerSorter using {@link TableContentProviderBase#compare}. */
	private class TableViewerSorter extends ViewerSorter {
		/** {@inheritDoc} */
		@Override
		public int compare(Viewer viewer, Object o1, Object o2) {
			return TableContentProviderBase.this.compare(viewer, o1, o2);
		}
	}
}
