/*-------------------------------------------------------------------------+
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.databinding;

import org.eclipse.core.databinding.validation.IValidator;
import org.eclipse.core.databinding.validation.ValidationStatus;
import org.eclipse.core.runtime.IStatus;

/**
 * {@link IValidator} for checking that a numeric value is positive or zero.
 * 
 * @author hattendorf
 */
public class NumberPositiveZeroValidator implements IValidator {

	/** Singleton instance. */
	public static final NumberPositiveZeroValidator INSTANCE = new NumberPositiveZeroValidator();

	/** {@inheritDoc} */
	@Override
	public IStatus validate(Object value) {
		if(!(value instanceof Number)) {
			return ValidationStatus.cancel("Internal: Expected a Number, but had a " +
					value.getClass());
		}
		if(((Number)value).doubleValue() < 0) {
			return ValidationStatus.cancel("Value must be positive or zero!");
		}
		return ValidationStatus.ok();
	}
}
