/*-------------------------------------------------------------------------+
| Copyright 2012 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.dialog;

import org.conqat.ide.commons.ui.dialog.MessageUtils;
import org.eclipse.swt.widgets.Display;

/**
 * This class contains additional methods w.r.t. {@link MessageUtils}.
 * 
 * @author bugariu
 */
public class MessageUtilsExtended {

	/** Temporary result for the asked question. */
	private static boolean tempQuestionResult;

	/** Asks question in the UI thread. */
	public static boolean askQuestion(final String title, final String message) {
		syncExec(new Runnable() {
			@Override
			public void run() {
				tempQuestionResult = MessageUtils.askQuestion(title, message);
			}
		});
		return tempQuestionResult;
	}

	/** Opens a warning dialog in the UI thread. */
	public static void showWarningInUIThread(final String title, final String message) {
		syncExec(() -> MessageUtils.showWarning(title, message));
	}

	/** Opens an info dialog in the UI thread. */
	public static void showInfoInUIThread(final String title, final String message) {
		syncExec(() -> MessageUtils.showInfo(title, message));
	}

	/** Execute runnable in the UI thread */
	private static void syncExec(Runnable runnable) {
		Display.getDefault().syncExec(runnable);
	}
}
