/*-------------------------------------------------------------------------+
| Copyright 2012 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.tablecell;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.viewers.CellLabelProvider;
import org.eclipse.jface.viewers.DecoratingStyledCellLabelProvider;
import org.eclipse.jface.viewers.DelegatingStyledCellLabelProvider.IStyledLabelProvider;
import org.eclipse.jface.viewers.ILabelProviderListener;
import org.eclipse.jface.viewers.StyledString;
import org.eclipse.swt.graphics.Image;
import org.fortiss.tooling.kernel.model.INamedElement;
import org.fortiss.tooling.kernel.ui.service.IModelElementHandlerService;

/**
 * {@link CellLabelProvider} for {@link INamedElement} to be used with
 * {@link DecoratingStyledCellLabelProvider}. Name and icon are obtained from
 * {@link IModelElementHandlerService}.
 * 
 * @author hoelzl
 */
public class IconNameLabelProvider implements IStyledLabelProvider {
	/** {@inheritDoc} */
	@Override
	public void removeListener(ILabelProviderListener listener) {
		// ignore
	}

	/** {@inheritDoc} */
	@Override
	public boolean isLabelProperty(Object element, String property) {
		return false;
	}

	/** {@inheritDoc} */
	@Override
	public void dispose() {
		// ignore
	}

	/** {@inheritDoc} */
	@Override
	public void addListener(ILabelProviderListener listener) {
		// ignore
	}

	/** {@inheritDoc} */
	@Override
	public StyledString getStyledText(Object element) {
		if(element instanceof INamedElement) {
			return new StyledString(IModelElementHandlerService.getInstance().getName((EObject)element));
		}
		return new StyledString("");
	}

	/** {@inheritDoc} */
	@Override
	public Image getImage(Object element) {
		if(element instanceof EObject) {
			return IModelElementHandlerService.getInstance().getIcon((EObject)element);
		}
		return null;
	}
}
