/*-------------------------------------------------------------------------+
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.utils;

import static org.conqat.ide.commons.ui.ui.WorkbenchUtils.getActiveWorkbenchPage;

import org.eclipse.emf.common.util.EList;
import org.eclipse.jface.action.IStatusLineManager;
import org.eclipse.ui.IActionBars;
import org.eclipse.ui.IViewSite;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.IWorkbenchPart;
import org.eclipse.ui.IWorkbenchPartSite;
import org.fortiss.tooling.kernel.model.constraints.ConstraintInstance;
import org.fortiss.tooling.kernel.model.constraints.FailedConstraintInstanceStatus;
import org.fortiss.tooling.kernel.model.constraints.IConstraintInstanceContainer;

/**
 * Methods for accessing the status line.
 * 
 * @author gareis
 */
public class StatusUtils {

	/**
	 * Returns a Status Line object of the current window.
	 * 
	 * @return the status line manager
	 */
	public static IStatusLineManager getStatusLine() {
		IWorkbenchPage page = getActiveWorkbenchPage();
		IWorkbenchPart part = page.getActivePart();
		IWorkbenchPartSite site = part.getSite();
		IViewSite vSite = (IViewSite)site;
		IActionBars actionBars = vSite.getActionBars();

		if(actionBars == null) {
			return null;
		}

		IStatusLineManager statusLine = actionBars.getStatusLineManager();
		if(statusLine == null) {
			return null;
		}
		return statusLine;
	}

	/**
	 * Writes messages into the status line of the current window.
	 * 
	 * @param message
	 *            the message
	 */
	public static void setStatusMessage(String message) {
		if(getStatusLine() != null) {
			getStatusLine().setMessage(message);
		}
	}

	/**
	 * This function is to calculate the status of all of the instances of a particular constraint.
	 * 
	 * @param constraintToFind
	 *            name of the constraint
	 * @param instanceContainer
	 *            contains the instance container for the current constraints that are active
	 * @param currentActiveConstraints
	 *            contains the names of the current active constraints
	 * @return true or false based on the status of the constraint (Failed or Success)
	 */

	public static boolean areAllInstancesSuccessful(String constraintToFind,
			IConstraintInstanceContainer instanceContainer, EList<String> currentActiveConstraints) {

		for(ConstraintInstance ci : instanceContainer.getConstraintInstances()) {
			if(constraintToFind.toString().equalsIgnoreCase(ci.getConstraintName())) {
				if(currentActiveConstraints.contains(constraintToFind.toString())) {
					if(ci.getConstraintName().equalsIgnoreCase(constraintToFind.toString())) {
						// If the constraint instance has a "failed status"
						if(ci.getStatus() instanceof FailedConstraintInstanceStatus) {
							return false;
						}
					}
				}
				return true;
			}
		}
		return false;
	}
}
