/*-------------------------------------------------------------------------+
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.compose;

import static org.eclipse.emf.ecore.util.EcoreUtil.delete;
import static org.fortiss.tooling.base.utils.ConstraintsBaseUtils.removeFromConstraintInstanceContainer;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.base.model.base.ConstraintInstanceContainer;
import org.fortiss.tooling.kernel.extension.IElementCompositor;
import org.fortiss.tooling.kernel.extension.data.IElementCompositionContext;
import org.fortiss.tooling.kernel.extension.data.Prototype;
import org.fortiss.tooling.kernel.model.constraints.ConstraintInstance;
import org.fortiss.tooling.kernel.model.constraints.IConstraintInstanceContainer;

/**
 * {@link IElementCompositor} implementation for {@link ConstraintInstanceContainer}s.
 * 
 * @author hoelzl
 */
public class ConstraintInstanceContainerCompositor<CIC extends IConstraintInstanceContainer>
		implements IElementCompositor<CIC> {

	/** {@inheritDoc} */
	@Override
	public boolean canCompose(CIC container, EObject contained, IElementCompositionContext context) {
		return contained instanceof ConstraintInstance;
	}

	/** {@inheritDoc} */
	@Override
	public boolean compose(CIC container, EObject contained, IElementCompositionContext context) {
		ConstraintInstance c = (ConstraintInstance)contained;
		container.getConstraintInstances().add(c);
		return true;
	}

	/** {@inheritDoc} */
	@Override
	public boolean canComposePrototype(Prototype prototype) {
		// As of now constraints should never be added by prototype.
		return false;
	}

	/** {@inheritDoc} */
	@Override
	public boolean canDecompose(EObject contained) {
		return contained instanceof ConstraintInstance;
	}

	/** {@inheritDoc} */
	@Override
	public boolean decompose(EObject contained) {
		removeFromConstraintInstanceContainer((ConstraintInstance)contained);
		delete(contained);
		return true;
	}
}
