/*-------------------------------------------------------------------------+
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.utils;

import static org.fortiss.tooling.base.utils.LayoutModelElementFactory.createOffsetOrientation;

import org.fortiss.tooling.base.model.layout.EOrientation;
import org.fortiss.tooling.base.model.layout.ILayoutData;
import org.fortiss.tooling.base.model.layout.ILayoutedModelElement;
import org.fortiss.tooling.base.model.layout.OffsetOrientation;
import org.fortiss.tooling.base.model.layout.Orientation;

/**
 * Utility class for {@link OffsetOrientation} layout data.
 * 
 * @author wandinger
 * @author hoelzl
 */
public final class OffsetOrientationUtils {

	/**
	 * Returns a {@link OffsetOrientation} layout data object with the given
	 * key.
	 * 
	 * @param layouted
	 *            the layouted model element
	 * @param key
	 *            the layout key
	 * @return the offset and orientation stored under the layout key
	 */
	public static OffsetOrientation
			getOffsetOrientation(ILayoutedModelElement layouted, String key) {
		for(ILayoutData ld : layouted.getLayoutData()) {
			if(ld.getKey().equals(key) || ld instanceof Orientation) {
				return (OffsetOrientation)ld;
			}
		}
		return null;
	}

	/**
	 * Sets a {@link Orientation} layout data object with the given key.
	 * 
	 * @param layouted
	 *            the layouted model element
	 * @param key
	 *            the layout key
	 * @param orientation
	 *            the orientation value
	 * @param offset
	 *            the offset
	 */
	public static void setOffsetOrientation(ILayoutedModelElement layouted, String key, int offset,
			EOrientation orientation) {
		Orientation old = getOffsetOrientation(layouted, key);
		if(old != null) {
			layouted.getLayoutData().remove(old);
		}
		Orientation o = createOffsetOrientation(offset, orientation, key);
		layouted.getLayoutData().add(o);
	}
}
