/*-------------------------------------------------------------------------+
| Copyright 2013 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.utils;

/**
 * Utility functions that deal with the underlying system.
 * 
 * @author ratiu
 */
public class SystemUtils {

	/** Returns true if we are in a Windows system. */
	public static boolean isWindowsOperatingSystem() {
		return System.getProperty("os.name").startsWith("Windows");
	}

	/**
	 * Converts an integer value representing an error into a string. If the exit code cannot be
	 * interpreted, then an empty string is returned.
	 */
	public static String interpretProcessExitValues(int exitValue) {
		if(!isWindowsOperatingSystem()) {
			switch(exitValue) {
				case 126:
					return "Command not found";
				case 139:
					return "Segmentation fault";
			}
		}
		return "";
	}
}
