/*-------------------------------------------------------------------------+
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.dnd;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.swt.dnd.DND;
import org.eclipse.swt.dnd.DropTargetAdapter;
import org.eclipse.swt.dnd.DropTargetEvent;
import org.eclipse.swt.widgets.Widget;
import org.fortiss.tooling.kernel.service.IConnectionCompositorService;

/**
 * {@link DropTargetAdapter} for completing an EObject connection via a drop
 * gesture. If the {@link IConnectionCompositorService} allows the composition
 * the {@link DND#DROP_LINK} detail is set as user feedback.
 * <p>
 * This implementation uses the raw SWT DND mechanism.
 * 
 * @author hoelzl
 */
public abstract class ConnectionCompositionDropTargetAdapter extends DropTargetAdapter {

	/** {@inheritDoc} */
	@Override
	public void drop(DropTargetEvent event) {
		ConnectionCompositionSource dragSource = getDragSourceFromTransfer();
		EObject target = getTargetModel(event.item);
		IConnectionCompositorService.getInstance().connect(dragSource.getDesignatedElement(), target,
				dragSource.getDesignatedParentElement(), null);
	}

	/** {@inheritDoc} */
	@Override
	public void dragOver(DropTargetEvent event) {
		ConnectionCompositionSource dragSource = getDragSourceFromTransfer();
		EObject target = getTargetModel(event.item);
		if(target == null || dragSource.getDesignatedElement() == null) {
			event.detail = DND.DROP_NONE;
			return;
		}
		if(IConnectionCompositorService.getInstance().canConnect(dragSource.getDesignatedElement(),
				target, dragSource.getDesignatedParentElement(), null)) {
			event.detail = DND.DROP_LINK;
			return;
		}
		event.detail = DND.DROP_NONE;
	}

	/** Returns the current target element. */
	protected abstract EObject getTargetModel(Widget dropTarget);

	/** Returns the transfered object. */
	private ConnectionCompositionSource getDragSourceFromTransfer() {
		return (ConnectionCompositionSource)CompositionServiceLocalDNDTransfer.getInstance()
				.getObject();
	}
}
