/*-------------------------------------------------------------------------+
| Copyright 2013 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal.introspection;

import org.eclipse.jface.viewers.ITreeContentProvider;
import org.eclipse.jface.viewers.Viewer;
import org.fortiss.tooling.kernel.introspection.IIntrospectionItem;
import org.fortiss.tooling.kernel.introspection.IIntrospectiveKernelService;
import org.fortiss.tooling.kernel.introspection.KernelIntrospectionSystemService;
import org.fortiss.tooling.kernel.service.IKernelIntrospectionSystemService;

/**
 * Content provider for the {@link KISSViewPart}.
 * 
 * @author hoelzl
 */
public class KISSViewerContentProvider implements ITreeContentProvider {
	/** {@inheritDoc} */
	@Override
	public void inputChanged(Viewer viewer, Object oldInput, Object newInput) {
		// ignore
	}

	/** {@inheritDoc} */
	@Override
	public void dispose() {
		// do nothing
	}

	/** {@inheritDoc} */
	@Override
	public boolean hasChildren(Object element) {
		Object[] objs = getChildren(element);
		return objs != null && objs.length > 0;
	}

	/** {@inheritDoc} */
	@Override
	public Object getParent(Object element) {
		if(element == IKernelIntrospectionSystemService.getInstance()) {
			return KernelIntrospectionSystemService.class;
		}
		if(element instanceof IIntrospectiveKernelService) {
			return IKernelIntrospectionSystemService.getInstance();
		}
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public Object[] getElements(Object inputElement) {
		if(inputElement == KernelIntrospectionSystemService.class) {
			return new Object[] {IKernelIntrospectionSystemService.getInstance()};
		}
		return getChildren(inputElement);
	}

	/** {@inheritDoc} */
	@Override
	public Object[] getChildren(Object parentElement) {
		if(parentElement instanceof IIntrospectionItem) {
			IIntrospectionItem item = (IIntrospectionItem)parentElement;
			if(item.getIntrospectionItems() != null) {
				// TODO(VA,19) if possible
				return item.getIntrospectionItems().stream()
						.filter(c -> c.showInIntrospectionNavigation()).toArray();
			}
		}
		return null;
	}
}
