/*-------------------------------------------------------------------------+
| Copyright 2016 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal.introspection.details.handler;

import org.conqat.ide.commons.ui.jface.TreeContentProviderBase;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.viewers.ITableLabelProvider;
import org.eclipse.jface.viewers.ITreeContentProvider;
import org.eclipse.jface.viewers.TableLabelProviderBase;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.ScrolledComposite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Tree;
import org.eclipse.swt.widgets.TreeColumn;
import org.eclipse.ui.dialogs.PatternFilter;
import org.fortiss.tooling.kernel.extension.IConstraintChecker;
import org.fortiss.tooling.kernel.introspection.IIntrospectionItem;
import org.fortiss.tooling.kernel.introspection.items.ConstraintCheckerServiceIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.service.IConstraintCheckerService;

/**
 * Introspection UI handler for {@link IIntrospectionItem}s provided by
 * {@link IConstraintCheckerService}.
 * 
 * @author hoelzl
 */
public final class ConstraintCheckerServiceIntrospectionDetailsUIHandler extends
		IntrospectionDetailsUIHandlerBase {

	/** {@inheritDoc} */
	@Override
	public Control createComposite(ScrolledComposite parent) {
		String h = "Type to search registered checkers:";
		String f = "Number of registered constraint checkers: " + countCheckers();
		return createFilteredTreeInTabFolder(parent, h, f, "Registered Checkers");
	}

	/** Computes the number of constraint checkers. */
	private int countCheckers() {
		int count = 0;
		for(Class<?> c : getInputObject().getHandlerKeyClasses()) {
			count += getInputObject().getHandlerList(c).size();
		}
		return count;
	}

	/** {@inheritDoc} */
	@Override
	protected void createTreeColumns(Tree tree) {
		TreeColumn col0 = new TreeColumn(tree, SWT.LEFT);
		col0.setText("Model Element / Checker");
		col0.setWidth(400);

		TreeColumn col1 = new TreeColumn(tree, SWT.LEFT);
		col1.setText("Model Element Class");
		col1.setWidth(400);

		TreeColumn col2 = new TreeColumn(tree, SWT.LEFT);
		col2.setText("Constraint Checker Implementation Class");
		col2.setWidth(400);
	}

	/** {@inheritDoc} */
	@Override
	protected ITreeContentProvider createContentProvider() {
		return new TreeContentProviderBase() {

			@Override
			public Object[] getChildren(Object parentElement) {
				if(parentElement == getInputObject()) {
					return getInputObject().getHandlerKeyClasses().toArray();
				} else if(parentElement instanceof Class) {
					return getInputObject().getHandlerList((Class<?>)parentElement).toArray();
				}
				return null;
			}
		};
	}

	/** {@inheritDoc} */
	@Override
	protected ITableLabelProvider createLabelProvider() {
		return new TableLabelProviderBase() {

			@SuppressWarnings("unchecked")
			@Override
			public String getColumnText(Object element, int columnIndex) {
				if(element instanceof Class) {
					switch(columnIndex) {
						case 0:
							return ((Class<?>)element).getSimpleName();
						case 1:
							return ((Class<?>)element).getName();
					}
				} else if(element instanceof IConstraintChecker) {
					IConstraintChecker<EObject> icc = (IConstraintChecker<EObject>)element;
					switch(columnIndex) {
						case 0:
							return icc.getClass().getSimpleName();
						case 2:
							return icc.getClass().getName();
					}
				}
				return "";
			}
		};
	}

	/** {@inheritDoc} */
	@Override
	protected PatternFilter createPatternFilter() {
		return new TableViewerPatternFilter();
	}

	/** {@inheritDoc} */
	@Override
	protected ConstraintCheckerServiceIntrospectionDetailsItem getInputObject() {
		return (ConstraintCheckerServiceIntrospectionDetailsItem)dataItem;
	}

	/** {@inheritDoc} */
	@Override
	protected boolean testSelection(Object selection) {
		return true;
	}

	/** {@inheritDoc} */
	@Override
	protected void populateContextMenu(Object selection, MenuManager mgr) {
		if(selection instanceof Class<?>) {
			mgr.add(createCopyClassNameAction((Class<?>)selection));
		} else if(selection instanceof IConstraintChecker<?>) {
			mgr.add(createCopyClassNameAction(selection.getClass()));
		}
	}
}
