/*-------------------------------------------------------------------------+
| Copyright 2016 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal.introspection.details.handler;

import org.eclipse.jface.viewers.ITreeContentProvider;
import org.eclipse.swt.custom.ScrolledComposite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Tree;
import org.fortiss.tooling.kernel.introspection.items.EObjectAwareIntrospectionDetailsItemBase;
import org.fortiss.tooling.kernel.ui.internal.ModelElementHandlerService;
import org.fortiss.tooling.kernel.ui.internal.introspection.details.DetailsUIHandlerBase;
import org.fortiss.tooling.kernel.ui.internal.introspection.items.ModelElementHandlerServiceIntrospectionDetailsItem;

/**
 * {@link DetailsUIHandlerBase} for {@link ModelElementHandlerService}.
 * 
 * @author hoelzl
 */
public final class ModelElementHandlerServiceIntrospectionDetailsUIHandler extends
		EObjectAwareIntrospectionDetailsUIHandlerBase {

	/** {@inheritDoc} */
	@Override
	public Control createComposite(ScrolledComposite parent) {
		String heading = "Type to search registered model element handlers:";
		String footer =
				"Number of currently registered model element handlers: " +
						getInputObject().countHandlers();
		return createFilteredTreeInTabFolder(parent, heading, footer, "Registered Handlers");
	}

	/** {@inheritDoc} */
	@Override
	protected void createTreeColumns(Tree tree) {
		createDefaultTreeColumns(tree, "Class / Handler", 250, "Handler Class", 400,
				"EObject Class", 400);
	}

	/** {@inheritDoc} */
	@Override
	protected ITreeContentProvider createContentProvider() {
		return new EObjectAwareTreeContentProviderBase() {
			@Override
			protected EObjectAwareIntrospectionDetailsItemBase<?> getInputObject() {
				return ModelElementHandlerServiceIntrospectionDetailsUIHandler.this
						.getInputObject();
			}
		};
	}

	/** {@inheritDoc} */
	@Override
	protected ModelElementHandlerServiceIntrospectionDetailsItem getInputObject() {
		return (ModelElementHandlerServiceIntrospectionDetailsItem)dataItem;
	}
}
