/*-------------------------------------------------------------------------+
| Copyright 2016 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal.introspection.details.handler;

import org.eclipse.jface.viewers.ITreeContentProvider;
import org.eclipse.swt.custom.ScrolledComposite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Tree;
import org.fortiss.tooling.kernel.introspection.items.EObjectAware2IntrospectionDetailsItemBase;
import org.fortiss.tooling.kernel.introspection.items.TransformationServiceIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.service.ITransformationService;

/**
 * Introspection UI handler for the {@link ITransformationService}.
 * 
 * @author hoelzl
 */
public final class TransformationServiceIntrospectionDetailsUIHandler extends
		EObjectAware2IntrospectionDetailsUIHandlerBase {

	/** {@inheritDoc} */
	@Override
	public Control createComposite(ScrolledComposite parent) {
		String heading = "Type to serach registered transformation providers:";
		String footer =
				"Number of currently registered transformation providers: " +
						getInputObject().countHandlers();
		return createFilteredTreeInTabFolder(parent, heading, footer, "Registered Providers");
	}

	/** {@inheritDoc} */
	@Override
	protected void createTreeColumns(Tree tree) {
		createDefaultTreeColumns(tree, "Source / Target / Provider", 250, "Provider Class", 400,
				"Source EObject Class", 400, "Target EObject Class", 400);
	}

	/** {@inheritDoc} */
	@Override
	protected ITreeContentProvider createContentProvider() {
		return new EObjectAware2TreeContentProviderBase() {
			@Override
			protected EObjectAware2IntrospectionDetailsItemBase<?> getInputObject() {
				return TransformationServiceIntrospectionDetailsUIHandler.this.getInputObject();
			}
		};
	}

	/** {@inheritDoc} */
	@Override
	protected TransformationServiceIntrospectionDetailsItem getInputObject() {
		return (TransformationServiceIntrospectionDetailsItem)dataItem;
	}
}
