/*-------------------------------------------------------------------------+
| Copyright 2016 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal.introspection.items;

import java.util.Map;
import java.util.Map.Entry;
import java.util.Set;

import org.fortiss.tooling.kernel.introspection.IIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.ui.extension.IConstraintUI;
import org.fortiss.tooling.kernel.ui.service.IConstraintUIService;

/**
 * {@link IIntrospectionDetailsItem} for {@link IConstraintUIService}.
 * 
 * @author hoelzl
 */
public final class ConstraintUIServiceIntrospectionDetailsItem implements IIntrospectionDetailsItem {

	/** Read-only copy of the services handler maps. */
	protected final Map<String, Class<? extends IConstraintUI>> handlerMap;

	/** Constructor. */
	public ConstraintUIServiceIntrospectionDetailsItem(
			Map<String, Class<? extends IConstraintUI>> handlerMap) {
		this.handlerMap = handlerMap;
	}

	/** Returns the registered constraint UI's along with their non-UI counterparts. */
	public Set<Entry<String, Class<? extends IConstraintUI>>> getHandlerKeyClasses() {
		return handlerMap.entrySet();
	}

	/** Returns the handler list for the given registration class. */
	public Class<? extends IConstraintUI> getHandler(String regClass) {
		return handlerMap.get(regClass);
	}
}
