/*-------------------------------------------------------------------------+
| Copyright 2015 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.extension;

import org.fortiss.tooling.kernel.extension.data.ILogMessageContext;
import org.fortiss.tooling.kernel.extension.data.LogMessage;
import org.fortiss.tooling.kernel.internal.LoggingService;
import org.fortiss.tooling.kernel.service.base.IObjectAware;

/**
 * The {@link LoggingService} provides registration and access to MessageHandlers that are used to
 * display messages emitted from non-UI, i.e. model, plugins to the user.
 * A {@link LogMessageHandler} knows how to present the given message to the user, e.g., the layout
 * or dialog style.
 * 
 * TODO(VA) Shouldn't this interface be called *I*LogMessageHandler?
 * 
 * @author diewald
 */
public interface LogMessageHandler<LM extends LogMessage> extends IObjectAware<LM> {
	/** Processes the {@link LogMessage} by the handler. */
	void showMessage(LM message, ILogMessageContext context);
}
