/*-------------------------------------------------------------------------+
| Copyright 2015 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.extension.data;

/**
 * {@link LogMessage} that additionally transports an Exception that can be processed by matching
 * handlers.
 * 
 * @author diewald
 */
public class LogMessageWithException extends LogMessage {
	/** The transported Exception. */
	protected final Exception exception;

	/**
	 * Constructor.
	 * 
	 * @param messageString
	 *            Message String that is transported by this {@link LogMessage}.
	 * @param e
	 *            Exception that is transported by this {@link LogMessage}..
	 */
	public LogMessageWithException(String messageString, Exception e) {
		super(messageString);
		this.exception = e;
	}

	/** Returns the Exception transported by this {@link LogMessage}. */
	public final Exception getException() {
		return exception;
	}
}
