/*-------------------------------------------------------------------------+
| Copyright 2016 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.introspection;

import static java.util.Collections.unmodifiableSet;

import java.util.HashSet;
import java.util.Set;

import org.fortiss.tooling.kernel.service.IKernelIntrospectionSystemService;

/**
 * Implementation of the kernel introspection system service (KISS).
 * 
 * @author hoelzl
 */
public final class KernelIntrospectionSystemService implements IKernelIntrospectionSystemService,
		IIntrospectiveKernelService {
	/** The singleton instance. */
	private static final KernelIntrospectionSystemService INSTANCE =
			new KernelIntrospectionSystemService();

	/** Returns singleton instance of the service. */
	public static KernelIntrospectionSystemService getInstance() {
		return INSTANCE;
	}

	/** The introspective services of the kernel. */
	private final HashSet<IIntrospectiveKernelService> services =
			new HashSet<IIntrospectiveKernelService>();

	/** {@inheritDoc} */
	@Override
	public void registerService(IIntrospectiveKernelService service) {
		System.out.println("[KISS] " + service.getIntrospectionLabel() + " registered.");
		services.add(service);
	}

	/** {@inheritDoc} */
	@Override
	public void unregisterService(IIntrospectiveKernelService service) {
		services.remove(service);
	}

	/** {@inheritDoc} */
	@Override
	public String getIntrospectionLabel() {
		return "Kernel Introspection System Service";
	}

	/** {@inheritDoc} */
	@Override
	public boolean showInIntrospectionNavigation() {
		return true;
	}

	/** {@inheritDoc} */
	@Override
	public Set<IIntrospectionItem> getIntrospectionItems() {
		return unmodifiableSet(services);
	}

	/** {@inheritDoc} */
	@Override
	public String getIntrospectionDescription() {
		return getIntrospectionLabel() +
				"\n\nThis service manages the kernel introspection system. Its purpose is to make all services" +
				"\nself-describing. All other kernel services register with it and provide their introspection" +
				"\ndata items, which can be reviewed from within the running kernel instance. This service " +
				"\nresembles the idea of the Linux kernel 'sysfs'.";
	}

	/** {@inheritDoc} */
	@Override
	public IIntrospectionDetailsItem getDetailsItem() {
		return null;
	}
}
