/*-------------------------------------------------------------------------+
| Copyright 2016 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.introspection.items;

import java.util.Collection;
import java.util.List;

import org.eclipse.core.resources.IFile;
import org.fortiss.tooling.kernel.extension.IEclipseResourceStorageLocationProvider;
import org.fortiss.tooling.kernel.extension.data.ModelStorageError;
import org.fortiss.tooling.kernel.introspection.IIntrospectionDetailsItem;
import org.fortiss.tooling.kernel.service.IEclipseResourceStorageService;

/**
 * {@link IIntrospectionDetailsItem} class for {@link IEclipseResourceStorageService}.
 * 
 * @author hoelzl
 */
public final class EclipseResourceStorageServiceIntrospectionDetailsItem implements
		IIntrospectionDetailsItem {

	/** Stores the registered storage providers. */
	private final List<IEclipseResourceStorageLocationProvider> storageProviderList;

	/** Cache of models loaded so far. */
	private final Collection<IFile> loadedContexts;

	/** List of failed model storage files. */
	private final List<ModelStorageError> errorFiles;

	/** Constructor. */
	public EclipseResourceStorageServiceIntrospectionDetailsItem(
			List<IEclipseResourceStorageLocationProvider> storageProviderList,
			Collection<IFile> loadedContexts, List<ModelStorageError> errorFiles) {
		this.storageProviderList = storageProviderList;
		this.loadedContexts = loadedContexts;
		this.errorFiles = errorFiles;
	}

	/** Returns the storage provider list. */
	public List<IEclipseResourceStorageLocationProvider> getStorageProviderList() {
		return storageProviderList;
	}

	/** Returns the loaded contexts. */
	public Collection<IFile> getLoadedFiles() {
		return loadedContexts;
	}

	/** Returns the error files. */
	public List<ModelStorageError> getErrorFiles() {
		return errorFiles;
	}
}
