/*-------------------------------------------------------------------------+
| Copyright 2016 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.spiderchart.style;

import static org.fortiss.tooling.spiderchart.util.FontUtils.VERDANA_10PT;
import static org.fortiss.tooling.spiderchart.util.FontUtils.VERDANA_12PT;
import static org.fortiss.tooling.spiderchart.util.FontUtils.VERDANA_14PT;
import static org.fortiss.tooling.spiderchart.util.FontUtils.VERDANA_16PT;
import static org.fortiss.tooling.spiderchart.util.FontUtils.VERDANA_18PT;
import static org.fortiss.tooling.spiderchart.util.FontUtils.VERDANA_8PT;
import static org.fortiss.tooling.spiderchart.util.RGBColorUtils.BLACK;

import org.eclipse.swt.graphics.FontData;
import org.eclipse.swt.graphics.RGB;

/**
 * Class for style attributes of fonts (FontData and SWT color).
 * 
 * @author hoelzl
 */
public final class FontStyle extends ColorStyleBase {

	/** Black Verdana 18 point. */
	public static final FontStyle BLACK_VERDANA_18PT = new FontStyle(VERDANA_18PT, BLACK);
	/** Black Verdana 16 point. */
	public static final FontStyle BLACK_VERDANA_16PT = new FontStyle(VERDANA_16PT, BLACK);
	/** Black Verdana 14 point. */
	public static final FontStyle BLACK_VERDANA_14PT = new FontStyle(VERDANA_14PT, BLACK);
	/** Black Verdana 12 point. */
	public static final FontStyle BLACK_VERDANA_12PT = new FontStyle(VERDANA_12PT, BLACK);
	/** Black Verdana 10 point. */
	public static final FontStyle BLACK_VERDANA_10PT = new FontStyle(VERDANA_10PT, BLACK);
	/** Black Verdana 8 point. */
	public static final FontStyle BLACK_VERDANA_8PT = new FontStyle(VERDANA_8PT, BLACK);

	/** The font data. */
	private final FontData fontData;

	/** Constructor. */
	public FontStyle(FontData fontData, RGB rgbColor) {
		super(rgbColor);
		this.fontData = fontData;
	}

	/** Returns font data. */
	public final FontData getFontData() {
		return fontData;
	}
}
