/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.marker;

import org.eclipse.core.resources.IMarker;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;

import org.conqat.ide.commons.ui.CCSMCommonsActivator;
import org.conqat.ide.commons.ui.logging.LoggingUtils;

/**
 * Utility methods related to the Eclipse marker mechanism.
 * 
 * @author heineman
 * @author $Author$
 * @version $Rev$
 * @levd.rating GREEN Hash: 54F4E07A41A44DC04C3DCD430F7764B4
 */
public class MarkerUtils {

	/**
	 * Creates a marker for the resource.
	 */
	public static IMarker createMarker(IResource resource, String description,
			String markerType) throws CoreException {

		IMarker marker = resource.createMarker(markerType);
		marker.setAttribute(IMarker.MESSAGE, description);

		return marker;
	}

	/**
	 * Removes markers from the resource.
	 */
	public static void removeMarkers(IResource resource, String markerType) {

		int depth = IResource.DEPTH_INFINITE;
		try {
			resource.deleteMarkers(markerType, true, depth);
		} catch (CoreException e) {
			LoggingUtils.error(CCSMCommonsActivator.getDefault(),
					"Markers could not be deleted!", e);
		}
	}

}