/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.resource;

import java.io.File;

import org.eclipse.core.resources.IContainer;
import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IFolder;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.Path;

import org.conqat.lib.commons.assertion.CCSMAssert;

/**
 * Class with utility methods for dealing with resources and the workspace.
 * 
 * @author deissenb
 * @author $Author: deissenb $
 * @version $Rev: 34252 $
 * @levd.rating GREEN Hash: 677BA03DBC5106C133C8175ED4833849
 */
public class ResourceUtils {

	/**
	 * Get a file from the workspace. The path must be workspace-relative. This
	 * method always returns a file. However, this does not necessarily exist.
	 */
	public static IFile getFile(String fullPath) {
		return ResourcesPlugin.getWorkspace().getRoot().getFile(
				new Path(fullPath));
	}

	/** Looks up the file for an eclipse resource. */
	public static File toFile(IResource resource) {
		IPath location = resource.getLocation();
		if (location == null) {
			return null;
		}
		return location.toFile().getAbsoluteFile();
	}

	/** Returns the absolute file for an eclipse path. */
	public static File toAbsoluteFile(IPath path, IProject project) {
		if (project.getFullPath().isPrefixOf(path)) {
			path = path.removeFirstSegments(project.getFullPath()
					.segmentCount());
		}
		return toFile(project.getFile(path));
	}

	/**
	 * Ensures that the given container and all of its parents exist. This
	 * expects that somewhere above the provided container is an existing
	 * {@link IFolder} ({@link IProject} is also an {@link IFolder}).
	 */
	public static void createContainer(IContainer container)
			throws CoreException {
		if (!container.exists()) {
			IContainer parent = container.getParent();
			createContainer(parent);
			CCSMAssert.isTrue(container instanceof IFolder,
					"Expect container to be within a folder hierarchy!");
			((IFolder) container).create(true, true, null);
		}
	}
}