/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.ui;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.jface.viewers.CellLabelProvider;
import org.eclipse.jface.viewers.EditingSupport;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.jface.viewers.TreeViewerColumn;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.dialogs.FilteredTree;
import org.eclipse.ui.dialogs.PatternFilter;
import org.eclipse.ui.progress.WorkbenchJob;

/**
 * Utility methods related to tree viewers.
 * 
 * @author $Author: juergens $
 * @version $Rev: 35087 $
 * @ConQAT.Rating GREEN Hash: 0D07A470A04AA381FDA01409DFDAA3B6
 */
public class TreeViewerUtils {

	/** Creates a filtered tree in the given composite. */
	public static FilteredTree createFilteredTree(Composite parent) {
		return createFilteredTree(parent, SWT.NONE);
	}

	/** Creates a filtered tree in the given composite. */
	public static FilteredTree createFilteredTree(Composite parent,
			int additionalFlags) {
		PatternFilter patternFilter = new PatternFilter();
		patternFilter.setIncludeLeadingWildcard(true);
		FilteredTree filteredTree = new FilteredTree(parent, SWT.V_SCROLL
				| SWT.H_SCROLL | SWT.MULTI | additionalFlags, patternFilter,
				true);

		return filteredTree;
	}

	/**
	 * Makes the filtered tree auto expand by adding a listener to the filter
	 * text control.
	 */
	public static void makeAutoExpandFilteredTree(
			final FilteredTree filteredTree) {
		filteredTree.getFilterControl().addModifyListener(new ModifyListener() {
			@Override
			public void modifyText(ModifyEvent e) {
				// we have to delay the expansion, as the filtered tree also
				// performs filtering (and collapsing) in a delayed job
				new WorkbenchJob("expand all") {
					@Override
					public IStatus runInUIThread(IProgressMonitor monitor) {
						filteredTree.getViewer().expandAll();
						return Status.OK_STATUS;
					}
				}.schedule(300);
			}
		});
	}

	/**
	 * Creates a column for a tree viewer.
	 * 
	 * @param editingSupport
	 *            the editing support (optional, may be null).
	 */
	public static TreeViewerColumn createColumn(TreeViewer viewer, String text,
			int width, int style, CellLabelProvider labelProvider,
			EditingSupport editingSupport) {
		TreeViewerColumn column = new TreeViewerColumn(viewer, style);

		column.getColumn().setText(text);
		column.getColumn().setWidth(width);
		column.setLabelProvider(labelProvider);
		if (editingSupport != null) {
			column.setEditingSupport(editingSupport);
		}

		return column;
	}
}